searchData={"items":[{"type":"module","title":"LiveSelect","doc":"The `LiveSelect` component is rendered by calling the `live_select/1` function and passing it a form field.\nLiveSelect creates a text input field in which the user can type text, and hidden input field(s) that will contain the value of the selected option(s).\n\nWhenever the user types something in the text input, LiveSelect triggers a `live_select_change` event for your LiveView or LiveComponent.\nThe message has a `text` parameter containing the current text entered by the user, as well as `id` and `field` parameters with the id of the\nLiveSelect component and the name of the LiveSelect form field, respectively.\nYour job is to handle the event, retrieve the list of selectable options and then call `Phoenix.LiveView.send_update/3`\nto send the list of options to LiveSelect. See the \"Examples\" section below for details, and check out the\n[cheatsheet](https://hexdocs.pm/live_select/cheatsheet.html) for some useful tips.\n\nSelection can happen either using the keyboard, by navigating the options with the arrow keys and then pressing enter, or by\nclicking an option with the mouse.\n\nWhenever an option is selected, `LiveSelect` will trigger a standard `phx-change` event in the form. See the \"Examples\" section\nbelow for details on how to handle the event.\n\nIn single mode, if the configuration option `allow_clear` is set, the user can manually clear the selection by clicking on the `x` button on the input field.\nIn tags mode, single tags can be removed by clicking on them.","ref":"LiveSelect.html"},{"type":"module","title":"Single mode - LiveSelect","doc":"","ref":"LiveSelect.html#module-single-mode"},{"type":"module","title":"Tags mode - LiveSelect","doc":"When `:tags` mode is enabled `LiveSelect` allows the user to select multiple entries. The entries will be visible above the text input field as removable tags.\n\nThe selected entries will be passed to your live view's `change` and `submit` event handlers as a list of entries, just like an [HTML   element with multiple attribute](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/multiple) would do.","ref":"LiveSelect.html#module-tags-mode"},{"type":"module","title":"Quick tags mode - LiveSelect","doc":"When `:quick_tags` mode is enabled, the user can select multiple entries, but the dropdown stays open after selection.\nThis allows the user to select additional entries in quick succession. Also, the entries can be deselected via the dropdown (as well as by clicking on the removable tags).\nThe dropdown closes when the `LiveSelect` element loses focus.","ref":"LiveSelect.html#module-quick-tags-mode"},{"type":"module","title":"Options - LiveSelect","doc":"You can set the initial list of options the user can choose from with the `options` assign.\nAfterwards, you can update the options at any time using `Phoenix.LiveView.send_update/3`.\nEach option will be assigned a label, which will be shown in the dropdown, and a value, which will be the value of the\nLiveSelect input when the option is selected.\n\n`options` can be any enumeration of the following elements:\n\n* _atoms, strings or numbers_: In this case, each element will be both label and value for the option\n* _tuples_: `{label, value}` corresponding to label and value for the option\n* _maps_: `%{label: label, value: value}` or `%{value: value}`\n* _keywords_: `[label: label, value: value]` or `[value: value]`\n\nIn the case of maps and keywords, if only `value` is specified, it will be used as both value and label for the option.\n\nBecause you can pass a list of tuples, you can use maps and keyword lists to pass the list of options, for example:\n\n```\n%{Red: 1, Yellow: 2, Green: 3}\n```\n\nWill result in 3 options with labels `:Red`, `:Yellow`, `:Green` and values 1, 2, and 3.\n\nNote that the option values, if they are not strings, will be JSON-encoded. Your LiveView will receive this JSON-encoded version in the `phx-change` and `phx-submit` events.","ref":"LiveSelect.html#module-options"},{"type":"module","title":"Styling - LiveSelect","doc":"`LiveSelect` supports 3 styling modes:\n\n* `tailwind`: uses standard tailwind utility classes (the default)\n* `daisyui`: uses [daisyUI](https://daisyui.com/) classes.\n* `none`: no styling at all.\n\nPlease see [the styling section](styling.md) for details","ref":"LiveSelect.html#module-styling"},{"type":"module","title":"Alternative tag labels - LiveSelect","doc":"Sometimes, in `:tags` mode, you might want to use alternative labels for the tags. For example, you might want the labels in the tags to be shorter\nin order to save space. You can do this by specifying an additional `tag_label` key when passing options as map or keywords. For example, passing these options:\n\n```\n[%{label: \"New York\", value: \"NY\", tag_label: \"NY\"}, %{label: \"Barcelona\", value: \"BCN\", tag_label: \"BCN\"}]\n```\n\nwill result in \"New York\" and \"Barcelona\" being used for the options in the dropdown, while \"NY\" and \"BCN\" will be used for the tags (and the values).","ref":"LiveSelect.html#module-alternative-tag-labels"},{"type":"module","title":"Sticky options - LiveSelect","doc":"Add  the `sticky: true` flag to an option to prevent it from being removed from the selection:\n\n```\n[%{label: \"New York\", value: \"NY\", sticky: true}]\n```\n\nNow, whenever the selection contains \"New York\", the option will stick and the user won't be able to remove it.","ref":"LiveSelect.html#module-sticky-options"},{"type":"module","title":"Slots - LiveSelect","doc":"You can control how your options and tags are rendered by using the `:option` and `:tag` slots.\nBoth slots will be passed an option as argument. In the case of the `:option` slot, the option will have an\nextra boolean field `:selected`, which will be set to `true` if the option has been selected by the user.\n\nLet's say you want to show some fancy icons next to each option in the dropdown and the tags:\n\n```elixir\n<.live_select\n        field={@form[:city_search]}\n        phx-target={@myself}\n        mode={:tags}\n      >\n        <:option :let={option}>\n           \n            <.globe />&nbsp;<%= option.label %>\n           \n        </:option>\n        <:tag :let={option}>\n            <.check />&nbsp;<%= option.label %>\n        </:tag>\n</.live_select>\n```\n\nHere's the result:","ref":"LiveSelect.html#module-slots"},{"type":"module","title":"Controlling the selection programmatically - LiveSelect","doc":"You can always control the selection programmatically, overriding the current user-selected values,\nby sending a `:value` update to `LiveSelect` via `Phoenix.LiveView.send_update/3`:\n\n```\nsend_update(LiveSelect.Component, id: live_select_id, value: new_selection)\n```\n\n`new_selection` must be a single element in `:single` mode, a list in `:tags` mode. If it's `nil`, the selection will be cleared.\nAfter updating the selection, `LiveSelect` will trigger a change event in the form.\n\nTo set a custom id for the component to use with `Phoenix.LiveView.send_update/3`, you can pass the `id` assign to `live_select/1`.","ref":"LiveSelect.html#module-controlling-the-selection-programmatically"},{"type":"module","title":"Examples - LiveSelect","doc":"These examples describe all the moving parts in detail. You can see these examples in action, see which messages and events are being sent, and play around\nwith the configuration easily with the [showcase app](https://github.com/maxmarcon/live_select#showcase-app).","ref":"LiveSelect.html#module-examples"},{"type":"module","title":"Single mode - LiveSelect","doc":"The user can search for cities.\nThe LiveSelect main form input is called `city_search`.\nWhen a city is selected, the coordinates of that city will be the value of the form input.\nThe name of the selected city is available in the text input field named `city_search_text_input`.\n\n_Template:_\n```\n<.form for={@form} phx-change=\"change\">\n  <.live_select field={@form[:city_search]} />\n</.form>\n```\n\n> #### Forms implemented in LiveComponents {: .warning}\n>\n> If your form is implemented in a LiveComponent and not in a LiveView, you have to add the `phx-target` attribute\n> when rendering LiveSelect:\n>\n> ```elixir\n>  <.live_select field={@form[:city_search]} phx-target={@myself} />\n> ```\n\n_LiveView or LiveComponent that is the target of the form's events:_\n```\n@impl true\ndef handle_event(\"live_select_change\", %{\"text\" => text, \"id\" => live_select_id}, socket) do\n    cities = City.search(text)\n    # cities could be:\n    # [ {\"city name 1\", [lat_1, long_1]}, {\"city name 2\", [lat_2, long_2]}, ... ]\n    #\n    # but it could also be (no coordinates in this case):\n    # [ \"city name 1\", \"city name 2\", ... ]\n    #\n    # or:\n    # [ [label: \"city name 1\", value: [lat_1, long_1]], [label: \"city name 2\", value: [lat_2, long_2]], ... ]\n    #\n    # or even:\n    # [\"city name 1\": [lat_1, long_1], \"city name 2\": [lat_2, long_2]]\n\n    send_update(LiveSelect.Component, id: live_select_id, options: cities)\n\n    {:noreply, socket}\nend\n\n@impl true\ndef handle_event(\n    \"change\",\n    %{\"my_form\" => %{\"city_search_text_input\" => city_name, \"city_search\" => city_coords}},\n    socket\n  ) do\n    IO.puts(\"You selected city #{city_name} located at: #{city_coords}\")\n\n    {:noreply, socket}\nend\n```","ref":"LiveSelect.html#module-single-mode"},{"type":"module","title":"Tags mode - LiveSelect","doc":"Let's say you want to build on the previous example and allow the user to select multiple cities and not only one.\nThe `:tags` mode allows you to do exactly this.\n\n_Template:_\n```\n<.form for={@form} phx-change=\"change\">\n  <.live_select field={@form[:city_search]} mode={:tags} />\n</.form>\n```\n\n_LiveView or LiveComponent that is the target of the form's events:_\n```\n@impl true\ndef handle_event(\n    \"change\",\n    %{\"my_form\" => %{\"city_search\" => list_of_coords}},\n    socket\n  ) do\n  # list_of_coords will contain the list of the JSON-encoded coordinates of the selected cities, for example:\n  # [\"[-46.565,-23.69389]\", \"[-48.27722,-18.91861]\"]\n\n  IO.puts(\"You selected cities located at: #{list_of_coords}\")\n\n  {:noreply, socket}\nend\n```","ref":"LiveSelect.html#module-tags-mode"},{"type":"module","title":"Multiple LiveSelect inputs in the same LiveView - LiveSelect","doc":"If you have multiple LiveSelect inputs in the same LiveView, you can distinguish them based on the field id.\nFor example:\n\n_Template:_\n```\n<.form for={@form} phx-change=\"change\">\n  <.live_select field={@form[:city_search]} />\n  <.live_select field={@form[:album_search]} />\n</.form>\n```\n\n_LiveView or LiveComponent:_\n```\n@impl true\ndef handle_event(\"live_select_change\", %{\"text\" => text, \"id\" => live_select_id, \"field\" => live_select_field}, socket) do\n  options =\n    case live_select_field do\n      \"form_name_city_search\" -> City.search(text)\n      \"form_name_album_search\" -> Album.search(text)\n    end\n\n  send_update(LiveSelect.Component, id: live_select_id, options: options)\n\n  {:noreply, socket}\nend\n```","ref":"LiveSelect.html#module-multiple-liveselect-inputs-in-the-same-liveview"},{"type":"module","title":"Using LiveSelect with associations and embeds - LiveSelect","doc":"LiveSelect can also be used to display and select associations or embeds without too much effort.\nLet's say you have the following schemas:\n\n```\ndefmodule City do\n  @moduledoc false\n\n  use Ecto.Schema\n\n  import Ecto.Changeset\n\n  @primary_key false\n  embedded_schema do\n    field(:name)\n    field(:pos, {:array, :float})\n  end\n\n  def changeset(%__MODULE__{} = schema \\\\ %__MODULE__{}, params) do\n    cast(schema, params, [:name, :pos])\n  end\nend\n\ndefmodule CitySearchForm do\n  use Ecto.Schema\n\n  import Ecto.Changeset\n\n  embedded_schema do\n    embeds_many(:city_search, City, on_replace: :delete)\n  end\n\n  def changeset(schema \\\\ %__MODULE__{}, params) do\n    cast(schema, params, [])\n    |> cast_embed(:city_search)\n  end\nend\n```\n\nEach city has a name and an array with coordinates - we want `LiveSelect` to display the name as label in the dropdown and in the tags, but we want\nthe entire data structure (name + coordinates) to be sent to the server when the user selects.\n\nIn order for this to work, we need to:\n\n1. Map `City` structs to the options expected by `LiveSelect`\n2. Decode `City` JSON objects sent by the client\n\nWe do (1) by passing a `value_mapper` assign to `LiveSelect`. This is a 1-arity function that expects the struct and maps it to the option that `LiveSelect` should use:\n\n```\n<.live_select field={@form[:city_search]} value_mapper={&value_mapper/1} mode={:tags} />\n```\n\n```\ndefp value_mapper(%City{name: name} = value) do\n  %{label: name, value: value}\nend\n```\n\nAs you can see, the label is the name of the city whereas the value is the entire struct. This is because we want to be able to recreate the struct from the value, so we need everything. `LiveSelect`\nuses `value_mapper/1` to map the values set in the form to the options expected by `LiveSelect`.\n\nYou can also use the `value_mapper/1` function to map values to options when updating the list of options while handling `live_select_change`:\n\n```\ndef handle_event(\"live_select_change\", %{\"text\" => text, \"id\" => live_select_id}, socket) do\n  options =\n    retrieve_options()\n    |> Enum.map(&value_mapper/1)\n\n  send_update(LiveSelect.Component, id: live_select_id, options: options)\n\n  {:noreply, socket}\nend\n```\n\n> #### IMPORTANT: the output of the `value_mapper/1` function should be JSON-encodable {: .warning}\n\nFinally, in order to take care of (2) you need to decode the JSON-encoded list of options that's coming from the client before you can\ncast them to create a changeset. To do so, `LiveSelect` offers a convenience function called `LiveSelect.decode/1`:\n```\ndef handle_event(\"change\", params, socket) do\n  # decode will JSON-decode the value in city_search, handling the type of selection\n  # and taking care of special values such as \"\" and nil\n  params = update_in(params, ~w(city_search_form city_search), &LiveSelect.decode/1)\n\n  # now we can cast the params:\n  changeset = CitySearchForm.changeset(params)\n\n  {:noreply, assign(socket, form: to_form(changeset))}\nend\n```\n\nThat's it! Now Your form with embeds selected and displayed with `LiveSelect` should work","ref":"LiveSelect.html#module-using-liveselect-with-associations-and-embeds"},{"type":"function","title":"LiveSelect.decode/1","doc":"Decodes the selection from the client. This has to be used when the values in the selection aren't simple integers or strings.\n\nLet's say you receive your params in the variable `params`, and your `LiveSelect` field is called `my_field` and belongs to the form `my_form`. Then you should\ndecode like this:\n\n```\nparams = update_in(params, ~w(my_form my_field), &LiveSelect.decode/1)\n```","ref":"LiveSelect.html#decode/1"},{"type":"function","title":"Examples: - LiveSelect.decode/1","doc":"iex> decode(nil)\n  []\n\n  iex> decode(\"\")\n  nil\n\n  iex> decode(\"{\\\"name\\\":\\\"Berlin\\\",\\\"pos\\\":[13.41053,52.52437]}\")\n  %{\"name\" => \"Berlin\",\"pos\" => [13.41053,52.52437]}\n\n  iex> decode([\"{\\\"name\\\":\\\"New York City\\\",\\\"pos\\\":[-74.00597,40.71427]}\",\"{\\\"name\\\":\\\"Stockholm\\\",\\\"pos\\\":[18.06871,59.32938]}\"])\n  [%{\"name\" => \"New York City\",\"pos\" => [-74.00597,40.71427]}, %{\"name\" => \"Stockholm\",\"pos\" => [18.06871,59.32938]}]","ref":"LiveSelect.html#decode/1-examples"},{"type":"function","title":"LiveSelect.live_select/1","doc":"Renders a `LiveSelect` input in a form.","ref":"LiveSelect.html#live_select/1"},{"type":"function","title":"Attributes - LiveSelect.live_select/1","doc":"* `field` (`:any`) (required) - a Phoenix.HTML.FormField struct identifying the form's field.\n* `id` (`:string`) - an id to assign to the component. If none is provided, `#{form_name}_#{field}_live_select_component` will be used.\n* `mode` (`:atom`) - either `:single` (for single selection), `:tags` (for multiple selection using tags), or `:quick_tags` (multiple selection but tags can be selected/deselected in quick succession). Defaults to `:single`.\n* `options` (`:list`) - initial available options to select from. Note that, after the initial rendering of the component, options can only be updated using `Phoenix.LiveView.send_update/3` - See the \"Options\" section for details.\n* `value` (`:any`) - used to manually set a selection - overrides any values from the form.\n    Must be a single element in `:single` mode, or a list of elements in `:tags` mode.\n\n* `max_selectable` (`:integer`) - limits the maximum number of selectable elements. `0` means unlimited. Defaults to `0`.\n* `user_defined_options` (`:boolean`) - if `true`, hitting enter will always add the text entered by the user to the selection. Defaults to `false`.\n* `allow_clear` (`:boolean`) - if `true`, when in single mode, display a \"x\" button in the input field to clear the selection.\n* `disabled` (`:boolean`) - set this to `true` to disable the input field.\n* `placeholder` (`:string`) - placeholder text for the input field.\n* `debounce` (`:integer`) - number of milliseconds to wait after the last keystroke before triggering a \"live_select_change\" event. Defaults to `100`.\n* `value_mapper` (`:any`) - function used to map the values from a form to LiveSelect options. Important: the output of this function should be JSON-encodable.\n* `update_min_len` (`:integer`) - the minimum length of text in the text input field that will trigger an update of the dropdown. Defaults to `1`.\n* `style` (`:atom`) - one of `:tailwind`, `:daisyui` or `:none`. See the [Styling section](styling.html) for details. Defaults to `:tailwind`.\n* `phx-target` (`:any`) - Optional target for events. Usually the same target as the form's.\n* `phx-blur` (`:string`) - Event to emit when the text input loses focus. The component id will be sent in the event's params.\n* `phx-focus` (`:string`) - Event to emit when the text input receives focus. The component id will be sent in the event's params.","ref":"LiveSelect.html#live_select/1-attributes"},{"type":"function","title":"Slots - LiveSelect.live_select/1","doc":"* `option` - optional slot that renders an option in the dropdown. The option's data is available via `:let`.\n* `tag` - optional slot that renders a tag. The option's data is available via `:let`.\n* `clear_button` - optional slot to render a custom clear button.","ref":"LiveSelect.html#live_select/1-slots"},{"type":"function","title":"Styling attributes - LiveSelect.live_select/1","doc":"* See [the styling section](styling.md) for details","ref":"LiveSelect.html#live_select/1-styling-attributes"},{"type":"module","title":"LiveSelect.Component","doc":"The module that implements the `LiveSelect` live component","ref":"LiveSelect.Component.html"},{"type":"function","title":"LiveSelect.Component.render/1","doc":"","ref":"LiveSelect.Component.html#render/1"},{"type":"extras","title":"Readme","doc":"# LiveSelect\n\n[![Hex](https://img.shields.io/hexpm/v/live_select.svg)](https://hex.pm/packages/live_select)\n[![Hexdocs](https://img.shields.io/badge/-docs-green)](https://hexdocs.pm/live_select)\n[![Elixir CI](https://github.com/maxmarcon/live_select/actions/workflows/elixir.yml/badge.svg)](https://github.com/maxmarcon/live_select/actions/workflows/elixir.yml)\n\nDynamic (multi)selection field for LiveView.\n\n`LiveSelect` is a LiveView component that implements a dynamic selection field with a dropdown. The content of the\ndropdown is filled by your LiveView as the user types. This allows you to easily create an \ninterface for search-like functionalities with type-ahead. `LiveSelect`s features include:\n\n* Single as well as multiple selection\n* Options to configure the behaviour, such as minimum number of characters that trigger an update or the maximum number of selectable options\n* Default styles for daisyUI and tailwindcss, which are fully customizable and can be completely overridden if needed\n* Ability to customize the rendered HTML for dropdown entries and tags using slots.\n\n### [Try it in the showcase app](https://live-select.fly.dev/) 🔬","ref":"readme.html"},{"type":"extras","title":"Single selection (single mode) - Readme","doc":"![DEMO](https://raw.githubusercontent.com/maxmarcon/live_select/main/priv/static/images/demo_single.gif)","ref":"readme.html#single-selection-single-mode"},{"type":"extras","title":"Multiple selection (tags mode) - Readme","doc":"![DEMO](https://raw.githubusercontent.com/maxmarcon/live_select/main/priv/static/images/demo_tags.gif)","ref":"readme.html#multiple-selection-tags-mode"},{"type":"extras","title":"Multiple selection (quick_tags mode) - Readme","doc":"![DEMO](https://raw.githubusercontent.com/maxmarcon/live_select/main/priv/static/images/demo_quick_tags.gif)","ref":"readme.html#multiple-selection-quick_tags-mode"},{"type":"extras","title":"Usage Example 🧭 - Readme","doc":"_Template:_\n\n```elixir\n  <.form for={@form} phx-change=\"change\">\n    <.live_select field={@form[:city_search]} /> \n  </.form>\n```\n\n**NOTE:** If your form is implemented in a LiveComponent, add `phx-target={@myself}`, like this:\n\n```elixir\n  <.live_select field={@form[:city_search]} phx-target={@myself} />\n```\n\n_In the LiveView or LiveComponent that's the target of your form events:_\n\n  ```elixir\n  @impl true\n  def handle_event(\"live_select_change\", %{\"text\" => text, \"id\" => live_select_id}, socket) do \n    cities = City.search(text)\n    # cities = [ \n    # {\"New York City\", [-74.00597,40.71427]}, \n    # {\"New Kingston\", [-76.78319,18.00747]}, \n    # ... \n    # ]\n\n    send_update(LiveSelect.Component, id: live_select_id, options: cities)\n    \n    {:noreply, socket}\n  end\n\n  @impl true\n  def handle_event(\n        \"change\",\n        %{\"my_form\" => %{\"city_search_text_input\" => city_name, \"city_search\" => city_coords}},\n        socket\n      ) do\n    IO.puts(\"You selected city #{city_name} located at: #{city_coords}\")\n\n    {:noreply, socket}\n  end  \n  ```\n\nRefer to the [module documentation](https://hexdocs.pm/live_select/LiveSelect.html) for the details, and\ncheck out the [cheatsheet](https://hexdocs.pm/live_select/cheatsheet.html) for some useful tips.","ref":"readme.html#usage-example"},{"type":"extras","title":"Installation 📦 - Readme","doc":"To install, add this to your dependencies:\n\n```elixir\n[\n    {:live_select, \"~> 1.0\"}\n]\n```","ref":"readme.html#installation"},{"type":"extras","title":"Javascript hooks 🪝 - Readme","doc":"`LiveSelect` relies on Javascript hooks to work. You need to add `LiveSelect`'s hooks to your live socket.\n`LiveSelect` distributes its Javascript code (a single file) in the same way as LiveView, by including an\nnpm package as part of its hex package.\n\nTo include `LiveSelect`'s hooks, add this to your `app.js` file:\n\n```javascript\nimport live_select from \"live_select\"\n\n// if you don't have any other hooks:\nlet liveSocket = new LiveSocket(\"/live\", Socket, {params: {_csrf_token: csrfToken}, hooks: live_select})\n\n// if you have other hooks:\nconst hooks = {\n    MyHook: {\n        // ...\n    },\n    ...live_select\n}\nlet liveSocket = new LiveSocket(\"/live\", Socket, {params: {_csrf_token: csrfToken}, hooks})\n```","ref":"readme.html#javascript-hooks"},{"type":"extras","title":"If you're using Webpack or another NPM-based builder - Readme","doc":"If you're using an npm-based builder such as Webpack, you will need to add `LiveSelect` to the list of your dependencies in your `package.json` (just as you did with LiveView):\n\n```js\n{\n  \"dependencies\": {\n    \"phoenix\": \"file:../deps/phoenix\",\n    \"phoenix_html\": \"file:../deps/phoenix_html\",\n    \"phoenix_live_view\": \"file:../deps/phoenix_live_view\",\n    \"live_select\":  \"file:../deps/live_select\" // <-- add this line, and add an extra \"../\" if you're in an umbrella app\n  }\n}\n```\n\nAnd then run `npm install` from your `assets` folder. You will also need to run `npm install --force live_select`\nwhenever you update the `LiveSelect` hex package in order to get the latest JS code.","ref":"readme.html#if-you-re-using-webpack-or-another-npm-based-builder"},{"type":"extras","title":"Styling 🎨 - Readme","doc":"`LiveSelect` supports 3 styling modes:\n\n* `tailwind`: uses standard tailwind utility classes (the default)\n* `daisyui`: uses [daisyUI](https://daisyui.com/) classes.\n* `none`: no styling at all.\n\nThe choice of style is controlled by the `style` option\nin [live_select/1](https://hexdocs.pm/live_select/LiveSelect.html#live_select/1).\n`tailwind` and `daisyui` styles come with sensible defaults which can be selectively extended or completely overridden.\n\nIf you're using `tailwind` or `daisyui` styles, you need to add one of the following lines to the `content` section in\nyour `tailwind.config.js`:\n\n```javascript\nmodule.exports = {\n    content: [\n        //...\n        '../deps/live_select/lib/live_select/component.*ex', // <-- for a standalone app\n        '../../../deps/live_select/lib/live_select/component.*ex' // <-- for an umbrella app\n    ]\n    //..\n}\n```\n\nNotice the different paths for a standalone or umbrella app.\n\nRefer to the [Styling section](https://hexdocs.pm/live_select/styling.html) for further details.","ref":"readme.html#styling"},{"type":"extras","title":"Showcase app 🎪 - Readme","doc":"The repository includes a showcase app that you can use to experiment with the different options and parameters\nfor `LiveSelect`.\nThe showcase app is available [here](https://live-select.fly.dev/).\n\nTo start the showcase app locally, simply run:\n\n```\nmix setup\nPORT=4001 mix phx.server\n```\n\nfrom within the cloned repository. The app will be available at http://localhost:4001. The showcase app allows you to\nquickly experiment with options and styles, providing an easy way to fine tune your `LiveSelect` component. The app also\nshows the messages and events that your `LiveView` receives. For each event or message, the app shows the function head\nof the callback that your LiveView needs to implement in order to handle the event.","ref":"readme.html#showcase-app"},{"type":"extras","title":"Contribute 🤝 - Readme","doc":"Contributions are very welcome! However, if you want do add a new feature please discuss it first by creating an issue so we can all agree that it's needed. \nAlso, it's important to add a test that covers it. If you don't know how to write the test or need guidance,\nI'm happy to help.\n\nUse `mix test` to run the entire test suite, which is subdivided into 3 main files:\n\n* `test/live_select/component_test.exs` - everything that can be tested by rendering the component statically\n* `test/live_select_test.exs` - tests for `single` mode that require a running LiveView \n* `test/live_select_tags_test.exs` - tests for `tags` mode that require a running LiveView\n\nTests that require a LiveView use the showcase app as the parent LiveView.","ref":"readme.html#contribute"},{"type":"extras","title":"Roadmap 🛣️ - Readme","doc":"- [X] Add `package.json` to enable `import live_select from \"live_select\"`\n- [X] Make sure component classes are included by tailwind\n- [X] Enable custom styling\n- [X] Rename LiveSelect.render to live_select\n- [X] Customizable placeholder\n- [X] Enable configuration of styles in the showcase app\n- [X] Add support for vanilla tailwind styles\n- [X] Enable multiple selection mode\n- [X] Expose as function component (and drop LV 0.17 support)\n- [X] Add cheatsheet\n- [X] Additional multiple selection mode \n- [ ] Add section to document testing strategies","ref":"readme.html#roadmap"},{"type":"extras","title":"Styling Guide","doc":"# Styling\n\n`LiveSelect` supports 3 styling modes:\n\n* `tailwind`: uses standard tailwind utility classes (the default)\n* `daisyui`: uses [daisyUI](https://daisyui.com/) classes.\n* `none`: no styling at all.\n\nThe choice of style is controlled by the `style` option in [live_select/1](`LiveSelect.live_select/1`).\n`tailwind` and `daisyui` styles come with sensible defaults which can be extended or overridden via options.\n\nThis is what each default style looks like:","ref":"styling.html"},{"type":"extras","title":"daisyui: - Styling Guide","doc":"(the actual colors may differ depending on the selected [daisyui theme](https://daisyui.com/docs/themes/))","ref":"styling.html#daisyui"},{"type":"extras","title":"tailwind: - Styling Guide","doc":"These defaults can be _selectively overridden or extended_ using the appropriate options\nto [live_select/1](`LiveSelect.live_select/1`).\n\nYou can control the style of the following elements:\n\n1. The outer **container** of the live_select component\n2. The **text input** field\n3. The **text input** field when an option has been selected\n4. The **dropdown** that contains the selectable options\n5. The single selectable **option**(s)\n6. The currently **active option**\n7. The **clear button** for the selection (if `allow_clear` is set)\n\nHere's a visual representation of the elements:\n\n![styled elements](https://raw.githubusercontent.com/maxmarcon/live_select/main/priv/static/images/styled_elements.png)\n\nIn `tags` and `quick_tags` mode there are 6 additional stylable elements:\n\n7. **tag** showing the selected options\n8. **tags_container** that contains the tags\n9. **selected_option**. This is an option in the dropdown that has already been selected. It's still visible, but can't be selected again\n11. **available_option**. This is an option in the dropdown that has not been selected and is available for selection \n10. **unavailable_option**. This is an option in the dropdown that has not been selected but is not available for selection. This happens when there is a specified maximum number of selectable elements and that number has been reached \n12. **clear buttons** to remove the tags\n\n![styled elements_tags](https://raw.githubusercontent.com/maxmarcon/live_select/main/priv/static/images/styled_elements_tags.png)\n\nFor each of these elements there is an `{element}_class` and for some also an `{element}_extra_class` option, which can\nbe used\nto override or extend the default CSS classes for the element, respectively. These options accept both strings and lists of strings.\nYou can't use both options together:\nuse `{element}_class`\nto completely override the default classes, or use `{element}_extra_class` to extend the default.\n\nThe following table shows the default styles for each element and the options you can use to adjust its CSS classes.\n\n| Element | Default daisyui classes | Default tailwind classes | Class override option | Class extend option |\n|----|----|----|----|----|\n| *active_option* | active | bg-gray-600 text-white | active_option_class |  |\n| *available_option* | cursor-pointer | cursor-pointer hover:bg-gray-400 rounded | available_option_class |  |\n| *clear_button* | cursor-pointer hidden | cursor-pointer hidden | clear_button_class | clear_button_extra_class |\n| *clear_tag_button* | cursor-pointer | cursor-pointer | clear_tag_button_class | clear_tag_button_extra_class |\n| *container* | dropdown dropdown-open | h-full relative text-black | container_class | container_extra_class |\n| *dropdown* | bg-base-200 dropdown-content menu menu-compact p-1 rounded-box shadow w-full z-[1] | absolute bg-gray-100 inset-x-0 rounded-md shadow top-full z-50 | dropdown_class | dropdown_extra_class |\n| *option* |  | px-4 py-1 rounded | option_class | option_extra_class |\n| *selected_option* | cursor-pointer font-bold | cursor-pointer font-bold hover:bg-gray-400 rounded | selected_option_class |  |\n| *tag* | badge badge-primary p-1.5 text-sm | bg-blue-400 flex p-1 rounded-lg text-sm | tag_class | tag_extra_class |\n| *tags_container* | flex flex-wrap gap-1 p-1 | flex flex-wrap gap-1 p-1 | tags_container_class | tags_container_extra_class |\n| *text_input* | input input-bordered pr-6 w-full | disabled:bg-gray-100 disabled:placeholder:text-gray-400 disabled:text-gray-400 pr-6 rounded-md w-full | text_input_class | text_input_extra_class |\n| *text_input_selected* | input-primary | border-gray-600 text-gray-600 | text_input_selected_class |  |\n| *unavailable_option* | disabled | text-gray-400 | unavailable_option_class |  |\n\nFor example, if you want to remove rounded borders from the options, have the active option use white text on a red background,\nand use green as a background color for tags instead of blue, render [live_select/1](`LiveSelect.live_select/1`)\nlike this:\n\n```\n<.live_select\n   form={my_form}\n   field={my_field}\n   id=\"live_select\"\n   mode={:tags}\n   placeholder=\"Search for a city\"\n   active_option_class=\"text-white bg-red-800\"\n   option_extra_class=\"!rounded\"\n   tag_extra_class=\"!bg-blue-400 bg-green-200\" />\n```\n\n> #### Selectively removing classes from defaults {: .tip}\n> \n> You can remove classes included with the style's defaults by using the *!class_name* notation\n> in an *{element}_extra_class* option. For example, if a default style is `rounded-lg px-4`,\n> using an extra class option of `!rounded-lg text-black` will result in the following final class \n> being applied to the element:\n> \n>  `px-4 text-black`","ref":"styling.html#tailwind"},{"type":"extras","title":"Cheatsheet","doc":"","ref":"cheatsheet.html"},{"type":"extras","title":"Style `LiveSelect` like a Phoenix Core Component, with label and errors - Cheatsheet","doc":"#### 1. Add this to `core_components.ex`:\n\n```elixir\ndef live_select(%{field: %Phoenix.HTML.FormField{} = field} = assigns) do\n  assigns =\n    assigns\n    |> assign(:errors, Enum.map(field.errors, &translate_error(&1)))\n    |> assign(:live_select_opts, assigns_to_attributes(assigns, [:errors, :label]))\n  \n  ~H\"\"\"\n   \n    <.label for={@field.id}><%= @label %></.label>\n     \n  \n    <.error :for={msg <- @errors}><%= msg %></.error>\n   \n  \"\"\"\nend\n```\n\n#### 2. Then call it this way:\n\n```elixir\n<.live_select field={@form[:city]} label=\"City\" phx-target={@myself} />\n```\n\nYou can also pass any of the other `LiveSelect` options.","ref":"cheatsheet.html#style-liveselect-like-a-phoenix-core-component-with-label-and-errors"},{"type":"extras","title":"Implementing a simple search functionality - Cheatsheet","doc":"","ref":"cheatsheet.html#implementing-a-simple-search-functionality"},{"type":"extras","title":"1. With no options displayed if the user doesn't enter any text - Cheatsheet","doc":"#### Heex template:\n\n```elixir\n<.live_select field={@form[:locations]} update_min_len={1} phx-focus=\"clear\" />\n```\n\n#### Live view:\n\n```elixir\n@impl true\ndef handle_event(\"live_select_change\", %{\"id\" => id, \"text\" => text}, socket) do\n options =\n   retrieve_locations()\n   |> Enum.filter(&(String.downcase(&1) |> String.contains?(String.downcase(text))))\n\n send_update(LiveSelect.Component, options: options, id: id)\n\n {:noreply, socket}\nend\n\n@impl true\ndef handle_event(\"clear\", %{\"id\" => id}, socket) do\n  send_update(LiveSelect.Component, options: [], id: id)\n\n  {:noreply, socket}\nend\n```","ref":"cheatsheet.html#1-with-no-options-displayed-if-the-user-doesn-t-enter-any-text"},{"type":"extras","title":"2. With a fixed set of default options to be displayed when the text input is empty - Cheatsheet","doc":"#### Heex template:\n\n```elixir\n<.live_select field={@form[:locations]} update_min_len={0} phx-focus=\"set-default\" options={@default_locations} />\n```\n\n#### Live view:\n\n```elixir\n@impl true\ndef mount(socket) do\n  socket = assign(socket, default_locations: default_locations())\n  \n  {:ok, socket}\nend\n\n@impl true\ndef handle_event(\"live_select_change\", %{\"id\" => id, \"text\" => text}, socket) do\n  options =\n    if text == \"\" do \n      socket.assigns.default_locations\n    else\n      retrieve_locations()\n      |> Enum.filter(&(String.downcase(&1) |> String.contains?(String.downcase(text))))\n    end\n    \n  send_update(LiveSelect.Component, options: options, id: id)\n    \n  {:noreply, socket}\nend\n\n@impl true\ndef handle_event(\"set-default\", %{\"id\" => id}, socket) do\n  send_update(LiveSelect.Component, options: socket.assigns.default_locations, id: id)\n\n  {:noreply, socket}\nend\n```","ref":"cheatsheet.html#2-with-a-fixed-set-of-default-options-to-be-displayed-when-the-text-input-is-empty"},{"type":"extras","title":"Dropdown that opens above the input field - Cheatsheet","doc":"{: .col-2}","ref":"cheatsheet.html#dropdown-that-opens-above-the-input-field"},{"type":"extras","title":"Tailwind - Cheatsheet","doc":"#### Heex template\n\n```elixir\n<.live_select\n   field={@form[:my_field]}\n   dropdown_extra_class=\"!top-full bottom-full\" />\n```","ref":"cheatsheet.html#tailwind"},{"type":"extras","title":"DaisyUI - Cheatsheet","doc":"#### Heex template\n\n```elixir\n<.live_select\n   field={@form[:my_field]}\n   style={:daisyui}\n   container_extra_class=\"dropdown-top\" />\n```","ref":"cheatsheet.html#daisyui"},{"type":"extras","title":"Display tags underneath the input field (Tailwind) - Cheatsheet","doc":"#### Heex template:\n\n```elixir\n<.live_select\n   field={@form[:my_field]}\n   mode={:tags}\n   container_extra_class=\"flex flex-col\"\n   dropdown_extra_class=\"top-11\"\n   tags_container_extra_class=\"order-last\" />\n```","ref":"cheatsheet.html#display-tags-underneath-the-input-field-tailwind"},{"type":"extras","title":"Limit the height of the dropdown and make it scrollable (Tailwind) - Cheatsheet","doc":"#### Heex template:\n\n```\n<.live_select\n   field={@form[:my_field]}\n   dropdown_extra_class=\"max-h-60 overflow-y-scroll\" />\n```","ref":"cheatsheet.html#limit-the-height-of-the-dropdown-and-make-it-scrollable-tailwind"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"},{"type":"extras","title":"1.5.2 (2024-12-28) - CHANGELOG","doc":"* Fix [bug](https://github.com/maxmarcon/live_select/issues/70) where the keyboard doesn't show on some mobile browsers if an element is already selected in single mode","ref":"changelog.html#1-5-2-2024-12-28"},{"type":"extras","title":"1.5.1 (2024-12-28) - CHANGELOG","doc":"* Add unavailable_option_class to style options that cannot be selected because of max_selectable > 0\n* Fix can't remove items in quick_tags mode via dropdown with max_selectable","ref":"changelog.html#1-5-1-2024-12-28"},{"type":"extras","title":"1.5.0 (2024-12-27) - CHANGELOG","doc":"* new quick_tags mode \n* showcase app: add toggle to style options as checkboxes","ref":"changelog.html#1-5-0-2024-12-27"},{"type":"extras","title":"1.4.4 (2024-12-07) - CHANGELOG","doc":"* support for LiveView 1.0.0","ref":"changelog.html#1-4-4-2024-12-07"},{"type":"extras","title":"1.4.3 (2024-10-28) - CHANGELOG","doc":"* add options clear_tag_button_class and clear_tag_button_extra_class to style button to clear tags\n* fix [bug](https://github.com/maxmarcon/live_select/issues/81) where selection was not restored after focus+blur when value is pre-selected or forced","ref":"changelog.html#1-4-3-2024-10-28"},{"type":"extras","title":"1.4.2 (2024-06-19) - CHANGELOG","doc":"do not restore selection after blur it it was cleard by hitting the clear button","ref":"changelog.html#1-4-2-2024-06-19"},{"type":"extras","title":"1.4.1 (2024-06-18) - CHANGELOG","doc":"* fix bug introduced by LV-1.0's new focus behavior (https://github.com/maxmarcon/live_select/issues/72)","ref":"changelog.html#1-4-1-2024-06-18"},{"type":"extras","title":"1.4.0 (2024-03-18) - CHANGELOG","doc":"* support for associations and embeds\n* add `value_mapper` assign and `decode/1` function","ref":"changelog.html#1-4-0-2024-03-18"},{"type":"extras","title":"1.3.3 (2024-02-06) - CHANGELOG","doc":"* add slot to render custom clear button\n* add option to extend clear button style","ref":"changelog.html#1-3-3-2024-02-06"},{"type":"extras","title":"1.3.2 (2024-01-26) - CHANGELOG","doc":"* updated dependencies, including updating `phoenix_html` to `4.0.0`","ref":"changelog.html#1-3-2-2024-01-26"},{"type":"extras","title":"1.3.1 (2023-12-06) - CHANGELOG","doc":"* bugfix: only set selection in client if event was sent to this component","ref":"changelog.html#1-3-1-2023-12-06"},{"type":"extras","title":"1.3.0 (2023-12-05) - CHANGELOG","doc":"* added support for selection recovery. Upon reconnection, the client sends an event (`selection_recovery`) that contains the latest selection. This allows recovery of the selection that was active before the view disconnected.","ref":"changelog.html#1-3-0-2023-12-05"},{"type":"extras","title":"1.2.2 (2023-10-21) - CHANGELOG","doc":"* daisyui3-compatible\n* arrowUp when there is no active option navigates to the last option\n* scroll options into view when they become active","ref":"changelog.html#1-2-2-2023-10-21"},{"type":"extras","title":"1.2.1 (2023-10-17) - CHANGELOG","doc":"* fix bug that was causing dropdown to overflow container (https://github.com/maxmarcon/live_select/issues/43)","ref":"changelog.html#1-2-1-2023-10-17"},{"type":"extras","title":"1.2.0 (2023-09-25) - CHANGELOG","doc":"* add `clear_button_class` option to style clear buttons for tags and selection\n* various bugfixes and improvements","ref":"changelog.html#1-2-0-2023-09-25"},{"type":"extras","title":"1.1.1 (2023-07-21) - CHANGELOG","doc":"* accept `sticky` flag in an option to prevent it from being removed (https://github.com/maxmarcon/live_select/pull/33)\n* when selection becomes empty, an update is triggered with a hidden field named after `live_select`'s field's name\n\n(thanks to https://github.com/shamanime for both changes)","ref":"changelog.html#1-1-1-2023-07-21"},{"type":"extras","title":"1.1.0 (2023-06-26) - CHANGELOG","doc":"* add `phx-focus` and `phx-blur` options to specify events to be sent to the parent upon focus and blur of the text input field\n* send live_select_change event directly from JS hook to save a round-trip\n* expects a single `field` assign of type `Phoenix.HTML.FormField` instead of separate form and field assigns (which is still supported but soft-deprecated with a warning)","ref":"changelog.html#1-1-0-2023-06-26"},{"type":"extras","title":"1.0.4 (2023-05-30) - CHANGELOG","doc":"* Do not use name attribute on non-input elements to prevent LV from crashing\n* Change default for update_min_len to 1","ref":"changelog.html#1-0-4-2023-05-30"},{"type":"extras","title":"1.0.3 (2023-03-31) - CHANGELOG","doc":"* Programmatically override selection with value assign\n* Only clear options if entered text is shorter than update_min_len and user types backspace\n\nBugfix: fix selection via mouseclick not working when rendering nested elements in the :option slot","ref":"changelog.html#1-0-3-2023-03-31"},{"type":"extras","title":"1.0.2 (2023-03-20) - CHANGELOG","doc":"styling options now also accept lists of strings","ref":"changelog.html#1-0-2-2023-03-20"},{"type":"extras","title":"1.0.1 (2023-02-18) - CHANGELOG","doc":"Bugfix: fix error when using atom form","ref":"changelog.html#1-0-1-2023-02-18"},{"type":"extras","title":"1.0.0 (2023-02-15) - CHANGELOG","doc":"This version introduces the following breaking changes and new features:\n\n* Rendering using a function component `<.live_select />` instead of the old function style (`<%= live_select ... %>`)\n* Dropping the message-based update cycle (which used `handle_info/2`) in favour of an event-based update cycle (which uses `handle_event/3`). This makes it much easier\nand more intuitive to use LiveSelect from another LiveComponent.\n* Ability to customize the default rendering of dropdown entries and tags using the `:option` and `:tag` slots \n\n** How to upgrade from version 0.x.x: **\n\n1. Instead of rendering LiveSelect in this way: `<%= live_select form, field, mode: :tags %>`, render it in this way: `<.live_select form={form} field={field} mode={:tags} />`\n2. Don't forget to add `phx-target={@myself}` if you're using LiveSelect from another LiveComponent\n3. Turn your `handle_info/2` implementations into `handle_event/3`:\n\nTurn this:\n\n```elixir\ndef handle_info(%ChangeMsg{} = change_msg, socket) do\n     options = retrieve_options(change_msg.text)\n    \n     send_update(LiveSelect.Component, id: change_msg.id, options: options)\n    \n     {:noreply, socket}\nend\n```\n\ninto:\n\n```elixir\ndef handle_event(\"live_select_change\", %{\"text\" => text, \"id\" => live_select_id}, socket) do\n    options = retrieve_options(text)\n    \n    send_update(LiveSelect.Component, id: live_select_id, options: options)\n    \n    {:noreply, socket}\nend\n```\n\n4. If you're rendering LiveSelect in a LiveComponent, you can now place your `handle_event/3` callback in the LiveComponent, there's no need to put the update logic in the view anymore","ref":"changelog.html#1-0-0-2023-02-15"},{"type":"extras","title":"0.4.1 (2023-02-07) - CHANGELOG","doc":"Bugfix: component now works event when strict Content Security Policy are set","ref":"changelog.html#0-4-1-2023-02-07"},{"type":"extras","title":"0.4.0 (2023-01-30) - CHANGELOG","doc":"* add `available_option_class` configuration option to style options that have not been selected yet\n* add `user_defined_options` configuration option to allow user to enter any tag\n* enable assigning a custom id to the component\n* enable programmatically clearing of the selection via `clear` assign\n* add `allow_clear` configuration option. If set, an `x` button will appear next to the text input in single mode. Clicking the button clears the selection","ref":"changelog.html#0-4-0-2023-01-30"},{"type":"extras","title":"Deprecations - CHANGELOG","doc":"LiveSelect.update_options/2 has been deprecated in favor of directly using Phoenix.LiveView.send_update/3","ref":"changelog.html#deprecations"},{"type":"extras","title":"0.3.3 (2023-01-15) - CHANGELOG","doc":"* set initial selection from the form or manually with `value` option\n* set initial list of available options with `options` option\n* add a `max_selectable` option to limit the maximum size of the selection","ref":"changelog.html#0-3-3-2023-01-15"},{"type":"extras","title":"0.3.2 (2023-01-03) - CHANGELOG","doc":"Bugfix: options in dropdown not always clickable because of race condition with blur event (https://github.com/maxmarcon/live_select/issues/7)","ref":"changelog.html#0-3-2-2023-01-03"},{"type":"extras","title":"0.3.1 (2022-12-15) - CHANGELOG","doc":"Bugfix: removed inputs_for because it was failing if the field is not an association","ref":"changelog.html#0-3-1-2022-12-15"},{"type":"extras","title":"0.3.0 (2022-12-15) - CHANGELOG","doc":"* tags mode\n* hide dropdown on escape key pressed","ref":"changelog.html#0-3-0-2022-12-15"},{"type":"extras","title":"0.2.1 (2022-10-25) - CHANGELOG","doc":"* when disabled option is used, also disable hidden input\n* style disabled text input in tailwind mode\n* fix problem with selection via mouseclick when an input field is underneath the dropdown\n* hide dropdown when user clicks away from component or input loses focus\n* show dropdown when input obtains focus again\n* using default black text in tailwind mode","ref":"changelog.html#0-2-1-2022-10-25"},{"type":"extras","title":"0.2.0 (2022-10-03) - CHANGELOG","doc":"* support for tailwind styles (now the default)\n* more opinionated default styles\n* ability to selectively remove classes from style defaults using the !class_name notation\n* rename option search_term_min_length to update_min_len\n* better error messages\n* various improvements to the showcase app","ref":"changelog.html#0-2-0-2022-10-03"},{"type":"extras","title":"0.1.4 (2022-09-20) - CHANGELOG","doc":"* raise if class and extra_class options are used in invalid combinations (https://github.com/maxmarcon/live_select/issues/2)","ref":"changelog.html#0-1-4-2022-09-20"},{"type":"extras","title":"Bugfixes - CHANGELOG","doc":"* route server events to the right live select component using the component `id` (https://github.com/maxmarcon/live_select/issues/1)","ref":"changelog.html#bugfixes"},{"type":"extras","title":"0.1.3 (2022-08-12) - CHANGELOG","doc":"* rename LiveSelect.update/2 to LiveSelect.update_options/2\n* add debounce option\n* add search delay option to showcase app\n* JSON-encode option values before assigning them to the hidden input field\n* add LiveSelect.ChangeMsg struct to be used as change message","ref":"changelog.html#0-1-3-2022-08-12"},{"type":"extras","title":"0.1.2 (2022-08-10) - CHANGELOG","doc":"* Disable input field via options\n* Placeholder text via options\n* Improve docs and showcase app\n* Remove setting component id via options","ref":"changelog.html#0-1-2-2022-08-10"},{"type":"extras","title":"Bugfixes - CHANGELOG","doc":"* Use atoms as field names, because strings are not accepted by Ecto forms","ref":"changelog.html#bugfixes"},{"type":"extras","title":"0.1.1 (2022-08-09) - CHANGELOG","doc":"* Remove all colors from default daisyui styles\n* Improve styling of showcase app\n* Improve docs\n* Remove the `msg_prefix` option in favor of `change_msg`","ref":"changelog.html#0-1-1-2022-08-09"},{"type":"extras","title":"0.1.0 (2022-08-09) - CHANGELOG","doc":"First version 🎉","ref":"changelog.html#0-1-0-2022-08-09"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}